import { parser } from 'lezer-d';
import { LRLanguage, indentNodeProp, flatIndent, continuedIndent, foldNodeProp, foldInside, LanguageSupport } from '@codemirror/language';

const dLanguage = /*@__PURE__*/LRLanguage.define({
    parser: /*@__PURE__*/parser.configure({
        props: [
            /*@__PURE__*/indentNodeProp.add({
                LabeledStatement: flatIndent,
                IfExpression: /*@__PURE__*/continuedIndent({ except: /^\s*({|else\b)/ }),
                TryStatement: /*@__PURE__*/continuedIndent({ except: /^\s*({|catch|finally)\b/ })
            }),
            /*@__PURE__*/foldNodeProp.add({
                Application: foldInside,
                BlockStatement: foldInside
            })
        ]
    }),
    languageData: {
        commentTokens: { line: "//", block: { open: "/*", close: "*/" }, nesting: { open: "/+", close: "+/" } },
        indentOnInput: /^\s*(\{|case |default:|finally )$/
    }
});
function d() {
    return new LanguageSupport(dLanguage);
}

export { d, dLanguage };
